@@ -53,8 +53,10 @@ namespace adaptive
                 void                setBytesRange   (const BytesRange &);
                 const BytesRange &  getBytesRange   () const;
                 virtual std::string getContentType  () const;
+                enum RequestStatus  getRequestStatus() const;
 
             protected:
+                enum RequestStatus  requeststatus;
                 size_t              contentLength;
                 BytesRange          bytesRange;
         };
@@ -65,6 +67,7 @@ namespace adaptive
                 virtual ~AbstractChunk();
 
                 std::string         getContentType          ();
+                enum RequestStatus  getRequestStatus        () const;
                 size_t              getBytesRead            () const;
                 uint64_t            getStartByteInFile      () const;
                 bool                isEmpty                 () const;
