@@ -2,7 +2,7 @@
  * video_widgets.c : OSD widgets manipulation functions
  *****************************************************************************
  * Copyright (C) 2004-2010 VLC authors and VideoLAN
- * $Id: d83a17f967e09491c30be29231aadf84757a8915 $
+ * $Id: 9644fe90cc94cd1265454b38427d178e5ac3d7d1 $
  *
  * Author: Yoann Peronneau <yoann@videolan.org>
  *         Laurent Aimar <fenrir _AT_ videolan _DOT_ org>
@@ -212,13 +212,16 @@ static subpicture_region_t *OSDIcon(int type, const video_format_t *fmt)
     const int x      = fmt->i_x_offset + fmt->i_visible_width - margin_ratio * size - width;
     const int y      = fmt->i_y_offset                        + margin_ratio * size;
 
+    if( width < 1 || height < 1 )
+        return NULL;
+
     subpicture_region_t *r = OSDRegion(__MAX(x, 0),
                                        __MIN(y, (int)fmt->i_visible_height - height),
                                        width, height);
     if (!r)
         return NULL;
 
-    DrawRect(r, STYLE_FILLED, COL_TRANSPARENT, 0, 0, width, height);
+    DrawRect(r, STYLE_FILLED, COL_TRANSPARENT, 0, 0, width - 1, height - 1);
 
     if (type == OSD_PAUSE_ICON) {
         int bar_width = width / 3;
