@@ -2,7 +2,7 @@
  * vout_wrapper.c: "vout display" -> "video output" wrapper
  *****************************************************************************
  * Copyright (C) 2009 Laurent Aimar
- * $Id: 10c615ea2a93844399f31a94da2af2ebe1ec32a3 $
+ * $Id: b02a59891ad64c0a924fd3737ed769a504f6a5a2 $
  *
  * Authors: Laurent Aimar <fenrir _AT_ videolan _DOT_ org>
  *
@@ -120,7 +120,6 @@ int vout_InitWrapper(vout_thread_t *vout)
 {
     vout_thread_sys_t *sys = vout->p;
     vout_display_t *vd = sys->display.vd;
-    video_format_t source = vd->source;
 
     sys->display.use_dr = !vout_IsDisplayFiltered(vd);
     const bool allow_dr = !vd->info.has_pictures_invalid && !vd->info.is_slow && sys->display.use_dr;
@@ -149,7 +148,7 @@ int vout_InitWrapper(vout_thread_t *vout)
         sys->display_pool = display_pool;
     } else if (!sys->decoder_pool) {
         sys->decoder_pool =
-            picture_pool_NewFromFormat(&source,
+            picture_pool_NewFromFormat(&vd->source,
                                        __MAX(VOUT_MAX_PICTURES,
                                              reserved_picture + decoder_picture - DISPLAY_PICTURE_COUNT));
         if (!sys->decoder_pool)
@@ -163,6 +162,13 @@ int vout_InitWrapper(vout_thread_t *vout)
         NoDrInit(vout);
     }
     sys->private_pool = picture_pool_Reserve(sys->decoder_pool, private_picture);
+    if (!sys->private_pool)
+    {
+        if (sys->decoder_pool != sys->display_pool)
+            picture_pool_Release(sys->decoder_pool);
+        sys->display_pool = sys->decoder_pool = NULL;
+        return VLC_EGENERIC;
+    }
     return VLC_SUCCESS;
 }
 
@@ -173,8 +179,9 @@ void vout_EndWrapper(vout_thread_t *vout)
 {
     vout_thread_sys_t *sys = vout->p;
 
-    if (sys->private_pool)
-        picture_pool_Release(sys->private_pool);
+    assert(vout->p->decoder_pool && vout->p->private_pool);
+
+    picture_pool_Release(sys->private_pool);
 
     if (sys->decoder_pool != sys->display_pool)
         picture_pool_Release(sys->decoder_pool);
